make_arena_row

Function make_arena_row 

fn make_arena_row<T, const N: usize>(
    image: &[T],
    row_buffer: &mut [T],
    source_y: usize,
    image_size: FilterImageSize,
    kernel_size: KernelShape,
) -> Result<(), ImageError>
where T: Default + Copy + Send + Sync + 'static, f64: AsPrimitive<T>,
Pads an image row with clamp strategy

This method copies real content into center of new buffer and filling leading and trailing physical padded parts with clamp strategy